@@ -13,7 +13,7 @@ immer_opcat <- function(a , hmean , min = 1 , max = 10 , maxiter = 200 ){
 	fac2 <- 4*fac
 	g2 <- harm_mean( round_squeeze( a * fac2 , digits=0 , min = min , max = max ))
     iter <- 0	
-	aint <- base::rep( 1E5 , base::length(a)) 
+	aint <- rep( 1E5 , length(a)) 
 	conv <- FALSE
 	#********
 	# iterations
@@ -31,12 +31,12 @@ immer_opcat <- function(a , hmean , min = 1 , max = 10 , maxiter = 200 ){
 		fac <- ( fac1 + fac2 ) / 2 
 		aint <- round_squeeze( a * fac , digits=0 , min = min , max = max )
 		g0 <- harm_mean( aint	)
-		change <- base::max( base::abs( aint - aint_old ))
+		change <- max( abs( aint - aint_old ))
 		if ( change == 0 ){ conv <- TRUE }
 		if ( iter == maxiter ){ conv <- TRUE }
 		iter <- iter + 1 
 	}		
-	base::return(aint)		
+	return(aint)		
 }
 #**************************************************
 
@@ -44,16 +44,16 @@ immer_opcat <- function(a , hmean , min = 1 , max = 10 , maxiter = 200 ){
 #***********************************************
 # compute harmonic mean
 harm_mean <- function( x ){
-    base::exp( base::mean( base::log(x) ) )
+    exp( mean( log(x) ) )
 }
 #***********************************************
 			
 #***********************************************
 # round and squeeze
 round_squeeze <- function( x , digits=0 , min = -Inf , max = Inf){
-    x1 <- base::round( x , digits = digits )
-    x1 <- base::ifelse( x1 < min , min , x1 )
-    x1 <- base::ifelse( x1 > max , max , x1 )
-    base::return(x1)
+    x1 <- round( x , digits = digits )
+    x1 <- ifelse( x1 < min , min , x1 )
+    x1 <- ifelse( x1 > max , max , x1 )
+    return(x1)
 }
 #***********************************************
