@@ -6,14 +6,14 @@ lpcm_generate_design <- function( pars_info , irtmodel , W ,
 	
 		W0 <- W
 		b0 <- b_const
-		n1 <- base::nrow(pars_info)
+		n1 <- nrow(pars_info)
 
-		if ( base::is.null(irtmodel) ){
+		if ( is.null(irtmodel) ){
 			irtmodel <- "PCM"
 		}
 		
-		if ( base::is.null( b_const ) ){
-				b_const <- base::rep( 0 , n1 )
+		if ( is.null( b_const ) ){
+				b_const <- rep( 0 , n1 )
 		}		
 		
 		
@@ -26,15 +26,15 @@ lpcm_generate_design <- function( pars_info , irtmodel , W ,
 		#*********************
 		if ( nullcats != "zeroprob" ){
 		    n2 <- n1
-			W <- base::matrix( 0 , nrow=n1 , ncol=n2-1)
-			base::rownames(W) <- base::paste0( pars_info$item , "_Cat" , pars_info$cat )
+			W <- matrix( 0 , nrow=n1 , ncol=n2-1)
+			rownames(W) <- paste0( pars_info$item , "_Cat" , pars_info$cat )
 		}
 
 		if ( nullcats == "zeroprob" ){
-		    n2 <- base::sum(pars_info$estpar)
-			W <- base::matrix( 0 , nrow=n1 , ncol=n2-1)
-			base::rownames(W) <- base::paste0( pars_info$item , "_Cat" , pars_info$cat )
-			if ( base::is.null( b_const ) ){
+		    n2 <- sum(pars_info$estpar)
+			W <- matrix( 0 , nrow=n1 , ncol=n2-1)
+			rownames(W) <- paste0( pars_info$item , "_Cat" , pars_info$cat )
+			if ( is.null( b_const ) ){
 				b_const[ pars_info$estpar == 0 ] <- 99
 			}
 			irtmodel <- "PCM"
@@ -44,44 +44,44 @@ lpcm_generate_design <- function( pars_info , irtmodel , W ,
 		# irtmodel == "PCM"
 		if (irtmodel == "PCM"){
 			pinfo2 <- pars_info[ pars_info$estpar == 1 , ]
-			n1 <- base::nrow(pinfo2)
+			n1 <- nrow(pinfo2)
 			n2 <- n1	
 			index <- pinfo2$index
 			# PCM: normalization = "first"
 			if ( normalization == "first" ){
-				W[ base::cbind( index[2:n1] , 1:(n2-1) ) ] <- 1
-				base::colnames(W) <- base::rownames(W)[index[-1]	]
+				W[ cbind( index[2:n1] , 1:(n2-1) ) ] <- 1
+				colnames(W) <- rownames(W)[index[-1]	]
 			}
 											
 			# PCM: normalization = "sum"
 			if ( normalization == "sum" ){
-				W[ base::cbind( index[1:(n1-1)] , 1:(n1-1) ) ] <- 1
+				W[ cbind( index[1:(n1-1)] , 1:(n1-1) ) ] <- 1
 				W[ index[n1] , ] <- -1 
-				base::colnames(W) <- base::rownames(W)[index[-n1]]	
+				colnames(W) <- rownames(W)[index[-n1]]	
 			}
 		}
 		
 		#--------------------------
 		# irtmodel == "PCM2"
 		if (irtmodel == "PCM2" ){
-		    items <- base::unique( base::paste(pars_info$item))
-			I <- base::max( pars_info$itemid )
-			base::colnames(W) <- paste0("w",1:(n1-1))
+		    items <- unique( paste(pars_info$item))
+			I <- max( pars_info$itemid )
+			colnames(W) <- paste0("w",1:(n1-1))
 			#--- normalization == "first"
 			if ( normalization == "first"){
 				# items
 				p1 <- pars_info[ pars_info$itemid > 1	, ]
-				W[ base::cbind( p1$index , p1$itemid - 1 ) ] <- p1$cat
-				base::colnames(W)[ base::seq(1 , I-1 ) ] <- items[-1]
+				W[ cbind( p1$index , p1$itemid - 1 ) ] <- p1$cat
+				colnames(W)[ seq(1 , I-1 ) ] <- items[-1]
 			}
 			#--- normalization == "sum"
 			if ( normalization == "sum"){
 				# items
 				p1 <- pars_info[ pars_info$itemid < I	, ]
-				W[ base::cbind( p1$index , p1$itemid  ) ] <- p1$cat
- 		        base::colnames(W)[ base::seq(1 , I-1 ) ] <- items[-I]				
+				W[ cbind( p1$index , p1$itemid  ) ] <- p1$cat
+ 		        colnames(W)[ seq(1 , I-1 ) ] <- items[-I]				
 				p1b <- pars_info[ pars_info$itemid == I , , drop=FALSE ]
-				for ( kk in base::seq(1,nrow(p1b) ) ){
+				for ( kk in seq(1,nrow(p1b) ) ){
 					W[ p1b$index[kk] , 1:(I-1) ] <- - p1b$cat[kk]
 				}
 			}				
@@ -90,26 +90,26 @@ lpcm_generate_design <- function( pars_info , irtmodel , W ,
 			p2 <- pars_info
 			p2$param <- 0
 			p2$param[ p2$cat < p2$maxK ] <- 1
-			p2$param <- ( p2$param > 0 ) * ( base::cumsum( p2$param ) + ( vv - 1 ) )
-			W[ base::cbind( p2$index , p2$param ) ] <- 1
+			p2$param <- ( p2$param > 0 ) * ( cumsum( p2$param ) + ( vv - 1 ) )
+			W[ cbind( p2$index , p2$param ) ] <- 1
 			p2a <- p2[ p2$param > 0 , ]
-			base::colnames(W)[ p2a$param ] <- base::paste0( p2a$item , "_Step" , p2a$cat )					
+			colnames(W)[ p2a$param ] <- paste0( p2a$item , "_Step" , p2a$cat )					
 		}
 
-		if ( ! base::is.null(W0) ){
+		if ( ! is.null(W0) ){
 			W <- W0 
 		}
-		if ( ! base::is.null(b0) ){
+		if ( ! is.null(b0) ){
 			b_const <- b0
 		}			
 														
-		if ( base::is.null( base::colnames(W) ) ){
-			base::colnames(W) <- base::paste0("par" , base::seq(1,base::ncol(W)) )
+		if ( is.null( colnames(W) ) ){
+			colnames(W) <- paste0("par" , seq(1,ncol(W)) )
 		}
 				
 		#*********************
 		# output
-		res <- base::list(W=W , b_const=b_const, irtmodel=irtmodel)
-		base::return(res)		
+		res <- list(W=W , b_const=b_const, irtmodel=irtmodel)
+		return(res)		
 }
-###############################################
\ No newline at end of file
+###############################################
