@@ -6,18 +6,18 @@
 .onAttach <- function(libname,pkgname){
   d <- utils::packageDescription("immer")
   d1 <- d$Version
-  base::packageStartupMessage(
-		base::paste("* " ,d$Package," " , d1 ," (",d$Date,")",sep="")  )
+  packageStartupMessage(
+		paste("* " ,d$Package," " , d1 ," (",d$Date,")",sep="")  )
 	}
 	
 	
 version <- function(pkg="immer"){
-  lib <- base::dirname(system.file(package = pkg))
+  lib <- dirname(system.file(package = pkg))
   d <- utils::packageDescription(pkg)
-  base::return( base::paste(d$Package,d$Version,d$Date,lib) )
+  return( paste(d$Package,d$Version,d$Date,lib) )
 }
 
 # .First.lib <- function(lib, pkg){
 #          library.dynam("sirt", package = pkg, lib.loc = lib)
 #          return(invisible(0))
-#        } 
\ No newline at end of file
+#        } 
